<?php

namespace Drupal\single_content_sync\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\node\NodeInterface;
use Drupal\single_content_sync\ContentExporterInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines controller to export content.
 *
 * @package Drupal\single_content_sync\Controller
 */
class ContentExportController extends ControllerBase {

  /**
   * The content exporter service.
   *
   * @var \Drupal\single_content_sync\ContentExporterInterface
   */
  protected $contentExporter;

  /**
   * ContentExportController constructor.
   *
   * @param \Drupal\single_content_sync\ContentExporterInterface $content_exporter
   *   The content exporter service.
   */
  public function __construct(ContentExporterInterface $content_exporter) {
    $this->contentExporter = $content_exporter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('single_content_sync.exporter')
    );
  }

  /**
   * Export content functionality.
   *
   * @param \Drupal\node\NodeInterface $node
   *   Selected node to export.
   *
   * @return array
   *   Export content.
   */
  public function export(NodeInterface $node) {
    $export_in_yaml = $this->contentExporter->doExportToYml($node);

    return [
      '#type' => 'textarea',
      '#title' => $this->t('Exported content'),
      '#attributes' => [
        'data-yaml-editor' => 'true',
      ],
      '#value' => $export_in_yaml,
    ];
  }

}
